# FSDC

The FuckingSimpleDirectoryComparator can find identical, different files and unique files in 2 folders and all of its subfolders.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install FSDC.

```bash
pip install fsdc
```

## Usage

Open a terminal and use the command compare_dir

```bash
compare_dir
```

For help type:

```bash
compare_dir -h
```